<?php
/**
 * Chinese(Traditional) language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author chinsan <chinsan@mail2000.com.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin
 * @author Shuo-Ting Jian <shoting@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = '編修本頁';
$lang['btn_source']            = '顯示原始碼';
$lang['btn_show']              = '顯示頁面';
$lang['btn_create']            = '建立此頁';
$lang['btn_search']            = '搜尋';
$lang['btn_save']              = '儲存';
$lang['btn_preview']           = '預覽';
$lang['btn_top']               = '回到頁頂';
$lang['btn_newer']             = '<< 較新';
$lang['btn_older']             = '較舊 >>';
$lang['btn_revs']              = '舊版';
$lang['btn_recent']            = '最近更新';
$lang['btn_upload']            = '上傳';
$lang['btn_cancel']            = '取消';
$lang['btn_index']             = '站台地圖';
$lang['btn_secedit']           = '改這段';
$lang['btn_login']             = '登入';
$lang['btn_logout']            = '登出';
$lang['btn_admin']             = '管理選單';
$lang['btn_update']            = '更新設定';
$lang['btn_delete']            = '刪除';
$lang['btn_back']              = '回上一步';
$lang['btn_backlink']          = '反向連結';
$lang['btn_backtomedia']       = '重新選擇圖檔';
$lang['btn_subscribe']         = '訂閱更動通知';
$lang['btn_profile']           = '更新個人資料';
$lang['btn_reset']             = '資料重設';
$lang['btn_resendpwd']         = '寄新密碼';
$lang['btn_draft']             = '編輯草稿';
$lang['btn_recover']           = '復原草稿';
$lang['btn_draftdel']          = '捨棄草稿';
$lang['btn_revert']            = '復原';
$lang['btn_register']          = '註冊';
$lang['btn_apply']             = '套用';
$lang['btn_media']             = '多媒體管理器';
$lang['loggedinas']            = '登入為';
$lang['user']                  = '帳號';
$lang['pass']                  = '密碼';
$lang['newpass']               = '新密碼';
$lang['oldpass']               = '目前密碼';
$lang['passchk']               = '確認密碼';
$lang['remember']              = '記住帳號密碼';
$lang['fullname']              = '真實姓名';
$lang['email']                 = 'E-Mail';
$lang['profile']               = '使用者個人資料';
$lang['badlogin']              = '很抱歉，您的使用者名稱或密碼可能有錯誤';
$lang['minoredit']             = '小修改';
$lang['draftdate']             = '草稿已自動存檔於';
$lang['nosecedit']             = '頁面在這之間已被修改，過時的區段資料已載入全頁取代。';
$lang['regmissing']            = '很抱歉，所有欄位都要填寫';
$lang['reguexists']            = '很抱歉，本帳號已被註冊';
$lang['regsuccess']            = '使用者已建立，密碼已寄發至該 email。';
$lang['regsuccess2']           = '使用者已建立';
$lang['regmailfail']           = '寄出密碼信似乎發生錯誤，請跟管理員聯絡！';
$lang['regbadmail']            = '您輸入的 email 似乎不對，如果您認為是正確的，請與管理員聯絡。';
$lang['regbadpass']            = '兩次輸入的密碼不一致，請再試一次。';
$lang['regpwmail']             = '您的 DokuWiki 帳號密碼';
$lang['reghere']               = '您還沒有帳號嗎？註冊一個吧。';
$lang['profna']                = '本維基不開放修改個人資料';
$lang['profnochange']          = '未做任何變更';
$lang['profnoempty']           = '帳號或 email 地址不可空白！';
$lang['profchanged']           = '個人資料已成功更新囉。';
$lang['pwdforget']             = '忘記密碼了？索取新密碼！';
$lang['resendna']              = '本維基不開放重寄密碼';
$lang['resendpwd']             = '寄新密碼給';
$lang['resendpwdmissing']      = '抱歉，您必須填寫所有欄位。';
$lang['resendpwdnouser']       = '抱歉，資料庫內找不到這個使用者';
$lang['resendpwdbadauth']      = '抱歉，認證碼無效。請確認您使用了完整的確認連結。';
$lang['resendpwdconfirm']      = '確認連結已通過郵件發送給您了。';
$lang['resendpwdsuccess']      = '您的新密碼已寄出。';
$lang['license']               = '若未特別註明，此維基上的內容都是採用以下授權方式：';
$lang['licenseok']             = '注意：編輯此頁面表示您已同意以下的授權方式：';
$lang['searchmedia']           = '搜尋檔名：';
$lang['searchmedia_in']        = '在 %s 裡搜尋';
$lang['txt_upload']            = '請選擇要上傳的檔案';
$lang['txt_filename']          = '請輸入要存在維基內的檔案名稱 (非必要)';
$lang['txt_overwrt']           = '是否要覆蓋原有檔案';
$lang['lockedby']              = '目前已被下列人員鎖定';
$lang['lockexpire']            = '預計解除鎖定於';
$lang['js']['willexpire']      = '本頁的編輯鎖定將在一分鐘內到期。要避免發生衝突，請按「預覽」鍵重設鎖定計時。';
$lang['js']['notsavedyet']     = '未儲存的變更將會遺失，繼續嗎？';
$lang['js']['searchmedia']     = '搜尋檔案';
$lang['js']['keepopen']        = '選擇時保持視窗開啟';
$lang['js']['hidedetails']     = '隱藏詳細內容';
$lang['js']['mediatitle']      = '連結設定';
$lang['js']['mediadisplay']    = '連結類型';
$lang['js']['mediaalign']      = '校正';
$lang['js']['mediasize']       = '圖像大小';
$lang['js']['mediatarget']     = '連結目標';
$lang['js']['mediaclose']      = '關閉';
$lang['js']['mediainsert']     = '插入';
$lang['js']['mediadisplayimg'] = '顯示此圖像';
$lang['js']['mediadisplaylnk'] = '只顯示連結';
$lang['js']['mediasmall']      = '小型版本';
$lang['js']['mediamedium']     = '中型版本';
$lang['js']['medialarge']      = '大型版本';
$lang['js']['mediaoriginal']   = '原始版本';
$lang['js']['medialnk']        = '連向內容頁面';
$lang['js']['mediadirect']     = '連向原始圖片';
$lang['js']['medianolnk']      = '不連結';
$lang['js']['medianolink']     = '不連結圖像';
$lang['js']['medialeft']       = '圖像靠左對齊';
$lang['js']['mediaright']      = '圖像靠右對齊';
$lang['js']['mediacenter']     = '圖像置中對齊';
$lang['js']['medianoalign']    = '不對齊';
$lang['js']['nosmblinks']      = '只有在 Microsoft IE 下才能執行「連結到 Windows shares」。
不過您仍可複製及貼上這個連結';
$lang['js']['linkwiz']         = '建立連結精靈';
$lang['js']['linkto']          = '連結至：';
$lang['js']['del_confirm']     = '確定刪除選取的項目？';
$lang['js']['restore_confirm'] = '確定還原到這個版本？';
$lang['js']['media_diff']      = '檢視差異:';
$lang['js']['media_diff_both'] = '並排';
$lang['js']['media_diff_opacity'] = '重疊';
$lang['js']['media_diff_portions'] = '滑動';
$lang['js']['media_select']    = '選擇檔案…';
$lang['js']['media_upload_btn'] = '上傳';
$lang['js']['media_done_btn']  = '完成';
$lang['js']['media_drop']      = '拖拉檔案到此上傳';
$lang['js']['media_cancel']    = '刪除';
$lang['js']['media_overwrt']   = '覆蓋已存在的檔案';
$lang['rssfailed']             = '擷取 RSS 饋送檔時發生錯誤：';
$lang['nothingfound']          = '沒找到任何結果。';
$lang['mediaselect']           = '媒體檔案';
$lang['fileupload']            = '上傳媒體檔案';
$lang['uploadsucc']            = '上傳成功';
$lang['uploadfail']            = '上傳失敗。似乎是權限錯誤？';
$lang['uploadwrong']           = '拒絕上傳。這個副檔名被禁止了！';
$lang['uploadexist']           = '檔案已存在，未處理。';
$lang['uploadbadcontent']      = '上傳檔案的內容不符合 %s 檔的副檔名';
$lang['uploadspam']            = '這次的上傳被垃圾訊息黑名單阻檔了。';
$lang['uploadxss']             = '這次的上傳因可能的惡意的內容而被阻檔。';
$lang['uploadsize']            = '上傳的檔案太大了 (最大：%s)';
$lang['deletesucc']            = '檔案 "%s" 已刪除。';
$lang['deletefail']            = '檔案 "%s" 無法刪除，請檢查權限定。';
$lang['mediainuse']            = '檔案 "%s" 未刪除，因為它正被使用。';
$lang['namespaces']            = '命名空間';
$lang['mediafiles']            = '可用的檔案有';
$lang['accessdenied']          = '您不被允許檢視此頁面';
$lang['mediausage']            = '使用以下的語法來連結此檔案:';
$lang['mediaview']             = '檢視原始檔案';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = '上傳檔案至目前的命名空間。要建立次級命名空間，將其名稱加在「上傳並重命名為」檔案名的前面，並用英文冒號隔開';
$lang['mediaextchange']        = '檔案類型已由 .%s 變更為 .%s !';
$lang['reference']             = '引用到本頁的，合計有';
$lang['ref_inuse']             = '此檔案無法刪除，因為它正被以下頁面使用：';
$lang['ref_hidden']            = '一些參考內容位於您沒有讀取權限的頁面中';
$lang['hits']                  = '個符合';
$lang['quickhits']             = '符合的頁面名稱';
$lang['toc']                   = '目錄表';
$lang['current']               = '目前版本';
$lang['yours']                 = '您的版本';
$lang['diff']                  = '顯示與目前版本的差異';
$lang['diff2']                 = '顯示選擇版本間的差異';
$lang['difflink']              = '連向這個比對檢視';
$lang['diff_type']             = '檢視差異:';
$lang['diff_inline']           = '行內';
$lang['diff_side']             = '並排';
$lang['line']                  = '行';
$lang['breadcrumb']            = '足跡';
$lang['youarehere']            = '您在這裡';
$lang['lastmod']               = '上一次變更';
$lang['by']                    = '由';
$lang['deleted']               = '移除';
$lang['created']               = '建立';
$lang['restored']              = '恢復為舊版';
$lang['external_edit']         = '外部編輯';
$lang['summary']               = '編輯摘要';
$lang['noflash']               = '顯示此內容需要 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>';
$lang['download']              = '下載程式碼片段';
$lang['mail_newpage']          = '增加的頁面:';
$lang['mail_changed']          = '變更的頁面:';
$lang['mail_subscribe_list']   = '命名空間中更動的頁面:';
$lang['mail_new_user']         = '新使用者:';
$lang['mail_upload']           = '已上傳檔案:';
$lang['changes_type']          = '檢視最近更新類型';
$lang['pages_changes']         = '頁面';
$lang['media_changes']         = '多媒體檔案';
$lang['both_changes']          = '頁面和多媒體檔案';
$lang['qb_bold']               = '粗體';
$lang['qb_italic']             = '斜體';
$lang['qb_underl']             = '底線';
$lang['qb_code']               = '程式碼';
$lang['qb_strike']             = '刪除線';
$lang['qb_h1']                 = 'H1 標題';
$lang['qb_h2']                 = 'H2 標題';
$lang['qb_h3']                 = 'H3 標題';
$lang['qb_h4']                 = 'H4 標題';
$lang['qb_h5']                 = 'H5 標題';
$lang['qb_h']                  = '標題';
$lang['qb_hs']                 = '選擇標題';
$lang['qb_hplus']              = '較大標題';
$lang['qb_hminus']             = '較小標題';
$lang['qb_hequal']             = '同等標題';
$lang['qb_link']               = '內部連結';
$lang['qb_extlink']            = '外部連結';
$lang['qb_hr']                 = '水平線';
$lang['qb_ol']                 = '有序列表項目';
$lang['qb_ul']                 = '無序列表項目';
$lang['qb_media']              = '加入圖片或檔案';
$lang['qb_sig']                = '插入簽名';
$lang['qb_smileys']            = '表情符號';
$lang['qb_chars']              = '特殊字元';
$lang['upperns']               = '前往父層命名空間';
$lang['admin_register']        = '新增使用者';
$lang['metaedit']              = '編輯後設資料';
$lang['metasaveerr']           = '後設資料寫入失敗';
$lang['metasaveok']            = '後設資料已儲存';
$lang['img_backto']            = '回上一頁';
$lang['img_title']             = '標題';
$lang['img_caption']           = '照片說明';
$lang['img_date']              = '日期';
$lang['img_fname']             = '檔名';
$lang['img_fsize']             = '大小';
$lang['img_artist']            = '攝影者';
$lang['img_copyr']             = '版權';
$lang['img_format']            = '格式';
$lang['img_camera']            = '相機';
$lang['img_keywords']          = '關鍵字';
$lang['img_width']             = '寬度';
$lang['img_height']            = '高度';
$lang['img_manager']           = '在多媒體管理器中檢視';
$lang['subscr_subscribe_success'] = '已將 %s 加入至 %s 的訂閱列表';
$lang['subscr_subscribe_error'] = '將 %s 加入至 %s 的訂閱列表時發生錯誤';
$lang['subscr_subscribe_noaddress'] = '沒有與您登入相關的地址，無法將您加入訂閱列表';
$lang['subscr_unsubscribe_success'] = '已將 %s 移除自 %s 的訂閱列表';
$lang['subscr_unsubscribe_error'] = '將 %s 移除自 %s 的訂閱列表時發生錯誤';
$lang['subscr_already_subscribed'] = '%s 已經被 %s 訂閱了';
$lang['subscr_not_subscribed'] = '%s 尚未被 %s 訂閱';
$lang['subscr_m_not_subscribed'] = '您尚未訂閱目前的頁面或命名空間。';
$lang['subscr_m_new_header']   = '加入訂閱';
$lang['subscr_m_current_header'] = '目前訂閱';
$lang['subscr_m_unsubscribe']  = '取消訂閱';
$lang['subscr_m_subscribe']    = '訂閱';
$lang['subscr_m_receive']      = '接收';
$lang['subscr_style_every']    = '每次更改都發送信件';
$lang['subscr_style_digest']   = '對每個頁面發送更改的摘要信件 (每 %.2f 天)';
$lang['subscr_style_list']     = '自上次發信以來更改的頁面的列表 (每 %.2f 天)';
$lang['authmodfailed']         = '帳號認證的設定不正確，請通知該維基管理員。';
$lang['authtempfail']          = '帳號認證目前暫不提供，若本狀況持續發生的話，請通知該維基管理員。';
$lang['i_chooselang']          = '選擇您的語系';
$lang['i_installer']           = 'DokuWiki 安裝工具';
$lang['i_wikiname']            = '維基名稱';
$lang['i_enableacl']           = '啟用 ACL (建議)';
$lang['i_superuser']           = '超級用戶';
$lang['i_problems']            = '安裝程式發現如下的問題。您必須修正它們才能繼續。';
$lang['i_modified']            = '出於安全考量，本腳本只能用於安裝全新且未修改的 Dokuwiki。
您可以重新解壓下載的封包或查閱完整的<a href=\"http://dokuwiki.org/install\">Dokuwiki 安裝指南</a>';
$lang['i_funcna']              = 'PHP 函數 <code>%s</code> 無法使用。也許您的主機供應者基於某些理由停用了它？';
$lang['i_phpver']              = '您的 PHP 版本 <code>%s</code> 比需要的版本 <code>%s</code> 還低。您必須更新您的PHP。';
$lang['i_permfail']            = '<code>%s</code> 無法被 DokuWiki 寫入。您必須修正該目錄的權限！';
$lang['i_confexists']          = '<code>%s</code> 已經存在';
$lang['i_writeerr']            = '無法建立 <code>%s</code>。您必須檢查目錄/檔案的權限並手動建立該檔案。';
$lang['i_badhash']             = '無法辨識或被變更的 dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - 非法或空白的值';
$lang['i_success']             = '設定已成功完成。您現在可以刪除 install.php 檔案。繼續到
<a href="doku.php">您的新 DokuWiki</a>.';
$lang['i_failure']             = '寫入設定檔時發生了一些錯誤。您必須在使用<a href="doku.php">您的新 Dokuwiki</a> 之前手動修正它們。';
$lang['i_policy']              = '初步的 ACL 政策';
$lang['i_pol0']                = '開放的維基 (任何人可讀取、寫入、上傳)';
$lang['i_pol1']                = '公開的維基 (任何人可讀取，註冊使用者可寫入與上傳)';
$lang['i_pol2']                = '封閉的維基 (只有註冊使用者可讀取、寫入、上傳)';
$lang['i_retry']               = '重試';
$lang['i_license']             = '請選擇您想要的內容發布許可協議：';
$lang['recent_global']         = '您正在閱讀命名空間： <b>%s</b> 中的變更。您亦可觀看整個維基的<a href="%s">最近更新</a>。';
$lang['years']                 = '%d 年前';
$lang['months']                = '%d 個月前';
$lang['weeks']                 = '%d 週前';
$lang['days']                  = '%d 天前';
$lang['hours']                 = '%d 個小時前';
$lang['minutes']               = '%d 分鐘前';
$lang['seconds']               = '%s 秒鐘前';
$lang['wordblock']             = '您的更改沒有被儲存，因为它包含被阻擋的文字 (垃圾訊息)。';
$lang['media_uploadtab']       = '上傳';
$lang['media_searchtab']       = '搜尋';
$lang['media_file']            = '檔案';
$lang['media_viewtab']         = '檢視';
$lang['media_edittab']         = '編輯';
$lang['media_historytab']      = '歷史紀錄';
$lang['media_list_thumbs']     = '縮圖';
$lang['media_list_rows']       = '列表';
$lang['media_sort_name']       = '名稱';
$lang['media_sort_date']       = '日期';
$lang['media_namespaces']      = '選擇命名空間';
$lang['media_files']           = '在 %s 中的檔案';
$lang['media_upload']          = '上傳至 %s';
$lang['media_search']          = '在 %s 中搜尋';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s 在 %s';
$lang['media_edit']            = '編輯 %s';
$lang['media_history']         = '%s 的歷史紀錄';
$lang['media_meta_edited']     = '元資料已編輯';
$lang['media_perm_read']       = '抱歉，您沒有足夠權限讀取檔案';
$lang['media_perm_upload']     = '抱歉，您沒有足夠權限上傳檔案。';
$lang['media_update']          = '上傳新的版本';
$lang['media_restore']         = '還原這個版本';
$lang['plugin_install_err']    = '插件安裝錯誤。將插件目錄 "%s" 重新命名為 "%s"';
